trait ShouldTerminateGracefully {
// Required method
fn should_terminate_gracefully(&self) -> bool;
}Expand description
A trait for errors that should terminate gracefully rather than panic the process.
Required Methods
Sourcefn should_terminate_gracefully(&self) -> bool
fn should_terminate_gracefully(&self) -> bool
Reports whether the error should terminate the process gracefully rather than panic.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".